@@ -30,7 +30,9 @@ with open(os.path.join(dir, 'ChannelAttribution.pyx')) as in_file:
             else:
                 out_file.write(line)
 				
-				
+
+if not os.path.exists(os.path.join(dir,"docs/")):
+    os.makedirs(os.path.join(dir,"docs/"))				
 
 os. chdir(os.path.join(dir,"docs/"))
 os.system("make clean && make html")
